.. include:: README_link.md
    :parser: myst_parser.sphinx_

Contents
--------

.. toctree::
    :maxdepth: 2
   
    api

Indices and tables
------------------

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`